@@ -128,7 +128,7 @@ class Install(InstallPlugin):
         answer = new_pass_caller.communicate()[0].split()[0]
         install_misc.set_debconf(self.target, 'mythtv/mysql_mythtv_password', answer)
 
-        os.remove(self.target + '/etc/mythtv/mysql.txt')
+        os.remove(self.target + '/etc/mythtv/config.xml')
         install_misc.reconfigure(self.target, 'mythtv-common')
 
     def setup_roles(self):
@@ -148,8 +148,6 @@ class Install(InstallPlugin):
                 shutil.copytree('/var/lib/mysql','/target/var/lib')
 
             #Setup sql server
-            #TODO, workaround for bug http://www.launchpad.net/bugs/729338
-            subprocess.call(['sysctl', '-w', 'kernel.yama.protected_nonaccess_hardlinks=0'])
             install_misc.reconfigure(self.target, 'mysql-server-5.5')
 
             #upstart managed chroot job, 
@@ -164,7 +162,6 @@ class Install(InstallPlugin):
 
             #Cleanup
             install_misc.chrex(self.target,'mysqladmin','--defaults-file=/etc/mysql/debian.cnf','shutdown')
-            subprocess.call(['sysctl', '-w', 'kernel.yama.protected_nonaccess_hardlinks=1'])
             proc.communicate()
 
             #Mythweb
