@@ -71,8 +71,13 @@ class Page(Plugin):
 
         if 'UBIQUITY_AUTOMATIC' not in os.environ:
             #if we are a Master type, we'll skip this page
-            type = self.db.get('mythbuntu/install_type')
-            if 'Master' in type:
+#
+#           Fixme: disabled since connection test is busted until 
+#		   python3 MythTV library ready
+#
+#            type = self.db.get('mythbuntu/install_type')
+#            if 'Master' in type:
+            if True:
                 os.environ['UBIQUITY_AUTOMATIC'] = "2"
                 #regrab the key in case it was supposed preseeded
                 key = self.ui.get_key()
@@ -111,11 +116,11 @@ class Install(InstallPlugin):
             os.makedirs(home_mythtv_dir)
 
         #Remove mysql.txt from home directory if it's there, then make one
-        sql_txt= home_mythtv_dir + '/mysql.txt'
-        if os.path.islink(sql_txt) or os.path.exists(sql_txt):
-            os.remove(sql_txt)
+        config_xml= home_mythtv_dir + '/config.xml'
+        if os.path.islink(config_xml) or os.path.exists(config_xml):
+            os.remove(config_xml)
         try:
-            os.symlink('/etc/mythtv/mysql.txt', sql_txt)
+            os.symlink('/etc/mythtv/config.xml', config_xml)
         except OSError:
             #on a live disk there is a chance this was a broken link
             #depending on what the user did in the livefs
@@ -124,7 +129,11 @@ class Install(InstallPlugin):
         #If they set a security key, try to copy it in
         try:
              import pwd
-             home_dir = pwd.getpwnam("ubuntu").pw_dir
+             uid = os.getenv('PKEXEC_UID', False)
+             if uid:
+                 home_dir = pwd.getpwuid(int(uid)).pw_dir
+             else:
+                 home_dir = pwd.getpwnam("mythbuntu").pw_dir
         except KeyError:
             home_dir = ''
         if key.isdigit() and os.path.exists(os.path.join(home_dir,'.mythtv','config.xml')):
